@@ -26,6 +26,9 @@
 #endif
 
 #include <gtk/gtk.h>
+
+#include <gdk/gdkx.h>
+
 #include <libxfce4util/libxfce4util.h>
 #include <garcon/garcon.h>
 #include <xfconf/xfconf.h>
@@ -73,7 +76,7 @@ main(int argc,
     if (G_UNLIKELY (opt_version))
     {
         g_print ("%s %s (Xfce %s)\n\n", G_LOG_DOMAIN, PACKAGE_VERSION, xfce_version_string());
-        g_print ("%s\n", "Copyright (c) 2008-2018");
+        g_print ("%s\n", "Copyright (c) 2008-2011");
         g_print ("\t%s\n\n", _("The Xfce development team. All rights reserved."));
         g_print (_("Please report bugs to <%s>."), PACKAGE_BUGREPORT);
         g_print ("\n");
@@ -102,7 +105,7 @@ main(int argc,
     }
 
     /* To prevent the settings dialog to be saved in the session */
-    gdk_set_sm_client_id ("FAKE ID");
+    gdk_x11_set_sm_client_id ("FAKE ID");
 
     gtk_main();
 
