@@ -713,7 +713,7 @@ clipboard_manager_process_event (GsdClipboardManager *manager,
         switch (xev->xany.type) {
         case DestroyNotify:
                 if (xev->xdestroywindow.window == manager->priv->requestor) {
-                        g_slist_foreach (manager->priv->contents, (GFunc) (void (*)(void)) target_data_unref, NULL);
+                        g_slist_foreach (manager->priv->contents, (GFunc) target_data_unref, NULL);
                         g_slist_free (manager->priv->contents);
                         manager->priv->contents = NULL;
 
@@ -741,7 +741,7 @@ clipboard_manager_process_event (GsdClipboardManager *manager,
                 if (xev->xselectionclear.selection == XA_CLIPBOARD_MANAGER) {
                         /* We lost the manager selection */
                         if (manager->priv->contents) {
-                                g_slist_foreach (manager->priv->contents, (GFunc) (void (*)(void)) target_data_unref, NULL);
+                                g_slist_foreach (manager->priv->contents, (GFunc) target_data_unref, NULL);
                                 g_slist_free (manager->priv->contents);
                                 manager->priv->contents = NULL;
 
@@ -754,7 +754,7 @@ clipboard_manager_process_event (GsdClipboardManager *manager,
                 }
                 if (xev->xselectionclear.selection == XA_CLIPBOARD) {
                         /* We lost the clipboard selection */
-                        g_slist_foreach (manager->priv->contents, (GFunc) (void (*)(void)) target_data_unref, NULL);
+                        g_slist_foreach (manager->priv->contents, (GFunc) target_data_unref, NULL);
                         g_slist_free (manager->priv->contents);
                         manager->priv->contents = NULL;
                         clipboard_manager_watch_cb (manager,
@@ -868,19 +868,11 @@ clipboard_manager_watch_cb (GsdClipboardManager *manager,
         GdkDisplay *display;
 
         display = gdk_display_get_default ();
-#if GTK_CHECK_VERSION (2, 24, 0)
         gdkwin = gdk_x11_window_lookup_for_display (display, window);
-#else
-        gdkwin = gdk_window_lookup_for_display (display, window);
-#endif
 
         if (is_start) {
                 if (gdkwin == NULL) {
-#if GTK_CHECK_VERSION (2, 24, 0)
                         gdkwin = gdk_x11_window_foreign_new_for_display (display, window);
-#else
-                        gdkwin = gdk_window_foreign_new_for_display (display, window);
-#endif
                 } else {
                         g_object_ref (gdkwin);
                 }
@@ -1016,13 +1008,13 @@ gsd_clipboard_manager_stop (GsdClipboardManager *manager)
         }
 
         if (manager->priv->conversions != NULL) {
-                g_slist_foreach (manager->priv->conversions, (GFunc) (void (*)(void)) conversion_free, NULL);
+                g_slist_foreach (manager->priv->conversions, (GFunc) conversion_free, NULL);
                 g_slist_free (manager->priv->conversions);
                 manager->priv->conversions = NULL;
         }
 
         if (manager->priv->contents != NULL) {
-                g_slist_foreach (manager->priv->contents, (GFunc) (void (*)(void)) target_data_unref, NULL);
+                g_slist_foreach (manager->priv->contents, (GFunc) target_data_unref, NULL);
                 g_slist_free (manager->priv->contents);
                 manager->priv->contents = NULL;
         }
