@@ -39,7 +39,6 @@
 #include <gdk/gdkx.h>
 #include <xfconf/xfconf.h>
 #include <libxfce4util/libxfce4util.h>
-#include <locale.h>
 
 #include <dbus/dbus-glib.h>
 
@@ -282,7 +281,7 @@ static void
 xfce_pointers_helper_syndaemon_check (XfcePointersHelper *helper)
 {
 #ifdef DEVICE_PROPERTIES
-    Display     *xdisplay = GDK_DISPLAY ();
+    Display     *xdisplay = GDK_DISPLAY_XDISPLAY(gdk_display_get_default());
     XDeviceInfo *device_list;
     XDevice     *device;
     gint         n, ndevices;
@@ -352,7 +351,6 @@ xfce_pointers_helper_syndaemon_check (XfcePointersHelper *helper)
         disable_duration = xfconf_channel_get_double (helper->channel,
                                                       "/DisableTouchpadDuration",
                                                       2.0);
-        setlocale(LC_NUMERIC, "C"); /* syndaemon needs a dot for the float. Nothing localized! */
         g_snprintf (disable_duration_string, sizeof (disable_duration_string),
                     "%.1f", disable_duration);
 
@@ -928,7 +926,7 @@ static void
 xfce_pointers_helper_restore_devices (XfcePointersHelper *helper,
                                       XID                *xid)
 {
-    Display         *xdisplay = GDK_DISPLAY ();
+    Display         *xdisplay = GDK_DISPLAY_XDISPLAY(gdk_display_get_default());
     XDeviceInfo     *device_list, *device_info;
     gint             n, ndevices;
     XDevice         *device;
@@ -1042,7 +1040,7 @@ xfce_pointers_helper_channel_property_changed (XfconfChannel      *channel,
                                                const GValue       *value,
                                                XfcePointersHelper *helper)
 {
-    Display      *xdisplay = GDK_DISPLAY ();
+    Display      *xdisplay = GDK_DISPLAY_XDISPLAY(gdk_display_get_default());
     XDeviceInfo  *device_list, *device_info;
     XDevice      *device;
     gint          n, ndevices;
